<?php
$lang['address'] = 'Adresse';
$lang['add_category'] = 'Kategorie hinzuf&uuml;gen';
$lang['add_icon'] = 'Neues Icon inzuf&uuml;gen';
$lang['add_map'] = 'Neue Karte hinzuf&uuml;gen';
$lang['add_map_point'] = 'Neuen Kartenpunkt hinzuf&uuml;gen';
$lang['add_point_for_map'] = 'Der Karte &quot;%s&quot; einen neuen Kartenpunkt hinzuf&uuml;gen';
$lang['aerial'] = 'Luft';
$lang['anchor_x'] = 'Anker X Pixel Ort';
$lang['anchor_y'] = 'Anker Y Pixel Ort';
$lang['apply'] = 'Best&auml;tigen';
$lang['ask_delete_icon'] = 'Wollen Sie wirklich dieses Icon aus der Liste entfernen (es werden keine Dateien gel&ouml;scht)?';
$lang['ask_reset_icons'] = 'Wollen Sie wirklich alle Icons entfernen und auf die programmseitigen Voreinstellungen zur&uuml;cksetzen?';
$lang['baloon_maptemplate'] = 'Ballon Template';
$lang['cancel'] = 'Abbrechen';
$lang['category_template'] = 'Kategorie-Template';
$lang['center_lat'] = 'Mitte Breitengrad';
$lang['center_lon'] = 'Mitte L&auml;ngengrad';
$lang['clearcache'] = 'Geolocate Cache leeren';
$lang['click'] = 'Klicken';
$lang['combine_points'] = 'Kombinieren einzelner Marker innerhalb der Reichweite';
$lang['combined_points_icon'] = 'Icon f&uuml;r kombinierte Nutzung';
$lang['controls'] = 'Bedienelemente';
$lang['controls_size'] = 'Gr&ouml;&szlig;e der Bedienelemente';
$lang['default'] = 'Standard';
$lang['default_icon'] = 'Standard Icon';
$lang['default_templates'] = 'Standard-Templates';
$lang['delete'] = 'L&ouml;schen';
$lang['delete_icon'] = 'Dieses Icon l&ouml;schen';
$lang['delete_map'] = 'Karte l&ouml;schen';
$lang['delete_map_point'] = 'Kartenpunkt l&ouml;schen';
$lang['description'] = 'Beschreibung';
$lang['directions'] = 'Bedienungsanleitung anzeigen';
$lang['directions_dest'] = 'Wo sollten Richtungen gezeichnet werden';
$lang['directions_units'] = 'Richtungs Einheiten';
$lang['dirform_maptemplate'] = 'Richtungs Formularvorlage';
$lang['dropdown'] = 'Dropdown';
$lang['edit'] = 'Bearbeiten';
$lang['edit_category'] = 'Marker Kategorie bearbieten';
$lang['edit_icon'] = 'Dieses Icon bearbeiten';
$lang['edit_map'] = 'Karte bearbeiten';
$lang['edit_map_point'] = 'Kartenpunkt bearbeiten';
$lang['edit_map_points'] = 'Kartenpunkte bearbeiten';
$lang['edit_points_for_map'] = 'Kartenpunkte f&uuml;r die Karte %s bearbeiten';
$lang['error_browser_incompatible'] = 'Dieser Browser kann, Google Maps nicht anzeigen';
$lang['error_cannotdelete'] = 'Dieser Eintrag konnte nicht entfernt werden';
$lang['error_deletecategory'] = 'Problem beim L&ouml;schen der Kategorie';
$lang['error_invalidparams'] = 'Ein oder mehrere Parameter sind entweder nicht vorhanden oder falsch.';
$lang['error_mapelem_notfound'] = 'Karten Element wurde nicht gefunden';
$lang['error_nameexists'] = 'Ein Element mit diesem Namen existiert bereits';
$lang['error_noapikey'] = 'Der Google-API-Key ist leer';
$lang['error_noapikey2'] = 'Der Google-API-Key ist leer. Solange dieser nicht mit einem g&uuml;ltigen Wert (so wie von Google angegeben) hinterlegt wurde, wird dieses Modul nicht richtig funktionieren.';
$lang['error_notfound'] = 'Das gew&uuml;nschte Element konnte nicht gefunden werden';
$lang['error_permissiondenied'] = 'Sie ben&ouml;tigen Sie die Berechtigung &#039;%s&#039;, um diese Funktion nutzen zu k&ouml;nnen.';
$lang['friendlyname'] = 'Calguys Google-Maps';
$lang['from'] = 'Von';
$lang['get_directions'] = 'Route';
$lang['google_api_key'] = 'Google-API-Key';
$lang['help'] = '<h3>Was macht dieses Modul</h3>
<p>Dies ist ein Ersatz (in Arbeit) f&uuml;r tsw&#039;s Googlemaps-Modul. Benutzer k&ouml;nnen damit einfach Google Maps erstellen. Die Berechtigungen k&ouml;nnen sehr detailliert eingestellt werden, so dass nur authorisierte Benutzer bestimmte Rechte haben. Au&szlig;erdem ist dynamisches Geo-Locating (mit Zwischenspeicherung) m&ouml;glich. Hiermit k&ouml;nnen direkte Adressen anstelle von GPS-Koordinaten  (L&auml;ngen- und Breitengrade) verwendet werden.</p>
<p>Dieses Modul erlaubt es, mehrere Karten auf einer Seite darzustellen und mehrere &quot;Marker&quot; bzw. Punkte auf jeder Karte zu platzieren. So kann dieses Modul &auml;hnlich wie Frapper verwendet werden.</p>
<h3>Wie wird dieses Modul eingesetzt?</h3>
<ul>
<li>Installieren Sie das Modul &uuml;ber die bekannten Vorgehensweisen</li>
<li>Richten Sie die Benutzer und Gruppen mit den entsprechenden Berechtigungen ein:
  <ul>
    <li>Mit der Berechtigung &#039;Manage Maps&#039; k&ouml;nnen Administratoren einzelne Karten hinzuf&uuml;gen, bearbeiten oder l&ouml;schen.</li>
    <li>Mit der Berechtigung &#039;Manage Map Locations&#039; k&ouml;nnen Administratoren einer Karte einzelne Punkte hinzuf&uuml;gen, bearbeiten oder l&ouml;schen.</li>
  </ul>
</li>
<li>Erstellen Sie eine Karte. Geben Sie dieser Karten einen Namen und legen dann die gew&uuml;nschten Parameter f&uuml;r diese Karte fest.</p>
<li>Markieren Sie eine Ihrer Karten als Standard, indem Sie auf das rote &#039;X&#039; neben der ensprechenden Karte klicken. Dies ist insbesondere dann n&uuml;tzlich, wenn Sie im Tag f&uuml;r den Modulaufruf den Parameter &#039;map&#039; nicht festgelegt wurde.</li>
<li>Erstellen Sie einen oder mehrere Punkte in dieser Karte, entweder durch Angabe der Breiten- und L&auml;ngengrade oder direkt &uuml;ber eine Adresse.</li>
<li>F&uuml;gen Sie dann noch den Tag {CGGoogleMaps} in eine Seite oder einem Seiten-Template ein. Das wars schon.</li>
</ul>
<br/>
<h3>Dynamisches Hinzuf&uuml;gen von Kartenpunkten</h3>
<p>Sie k&ouml;nnen Smarty verwenden, um dem Modul Kartenpunkte dynamisch hinzuzuf&uuml;gen.  Diese Funktion kann so verwendet werden, dass Sie eine Karte wie aus dem Online-Dienst Frappr bekannt erstellen, bei dem die Kartenpunkte dynamisch aus einem anderen Modul (zum Beispiel CompanyDirectory oder FrontEndUsers) generiert werden.</p>
<h4>Das {cggm_add_dynpoint} Smarty-Plugin</h4>
<p>Mit diesem Smarty-Plugin k&ouml;nnen Sie einer vorgegebenen Karte Kartenpunkte dynamisch hinzugef&uuml;gt werden. <em>(Das Plugin funktioniert jedoch nur bei installiertem CGGoogleMaps-Modul.</em></p>
<h5>Parameter:<h5>
  <ul> 
<li><strong>Pflichtfeld</strong> map -- die ID der Karte, der der Kartenpunkt hinzugef&uuml;gt werden soll</li>
<li><strong>Pflichtfeld</strong> name -- der Name des Kartenpunktes, der hinzugef&uuml;gt werden soll</li>
<li><em>optional</em> description -- der HTML-Inhalt, der in der aufklappenden Sprechblase angezeigt werden soll</li>
<li><em>optional</em> address -- die Adresse des Ortes, der hinzugef&uuml;gt werden soll</li>
<li><em>optional</em> lat -- der Breitengrad des Ortes, der hinzugef&uuml;gt werden soll</li>
<li><em>optional</em> long -- der L&auml;ngengrad des Ortes, der hinzugef&uuml;gt werden soll</li>
<li><em>optional</em> icon -- der Name des Icons, welcher f&uuml;r diesen Punkt verwendet werden soll</li>
  </ul>
<br/>
<p><strong>Hinweis 1:</strong> Sie m&uuml;ssen entweder die Breiten- und L&auml;ngengrade oder eine Adresse angeben.</p>
<p><strong>Hinweis 2:</strong> Dieses Plugin hat keine direkte Ausgabe. Im Fehlerfall erfolgt einfach nichts. Umgekehrt wird der Kartenpunkt in der Google-Karte angezeigt, wenn die richtigen Parameter angegeben wurden.</p>
</ul>';
$lang['height'] = 'H&ouml;he';
$lang['help_anchor_location'] = '<strong>Note:</strong>&nbsp;Anchor locations specify the pixel location (relative to the top left corner of thie image) where the icon should be anchored to the marker.  If no value is specified, the center of the icon will be used';
$lang['help_icon_url'] = 'Specify the URL to the pre-uploaded PNG image.  This image should not be larger than 32x32, and should support transparency.  The URL can usually be specified relative to the root of your installation';
$lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page.';
$lang['help_param_map'] = 'Specify the ID or map name to use for laying out the google map.  If this parameter is not specified, the default map (if any) is used.';
$lang['help_param_maptemplate'] = 'Specify the name of an existing, non default map template to use for this output.  If this parameter is not specified, the current default map template will be used';
$lang['help_param_zoomlevel'] = '(integer) Allows overriding the zoom level stored with the map.  Valid values are from 1 to 17';
$lang['help_param_zoomencompass'] = '(boolean) Allows overriding the zoom encompass setting that is stored with the map.';
$lang['hide_directions'] = 'Richtungen verbergen';
$lang['horizontal_bar'] = 'Horizontale Leiste';
$lang['hybrid'] = 'Hybrid-Modus';
$lang['id'] = 'ID';
$lang['icon'] = 'Icon ';
$lang['imperial'] = 'Imperial';
$lang['info'] = 'Information';
$lang['info_address_latlong'] = 'Hinweis: <strong>Entweder</strong> eine Adresse <strong>oder</strong> die geografische Breite und L&auml;nge eingeben. Wenn die Adresse und die geografische Breite und L&auml;nge eingegeben werden, hat die geografische Breite und L&auml;nge Vorrang.';
$lang['info_anchor_x'] = 'Info Fenster Anker X Pixel Ort';
$lang['info_anchor_y'] = 'Info Fenster Anker Y Pixel Ort';
$lang['info_bounds_fudge'] = 'When zoom encompass is specified you can specify a percentage <em>(in decimal)</em> by which to expand the map bounds to provide a &quot;margin&quot; around the encompassed points';
$lang['info_category_panel'] = 'Should a panel be displayed that shows the categories of all of the map points, and allow toggling map markers on and off by category';
$lang['info_center_lat'] = 'The Center latitude is optional.  If specified it will be used for centering the map.  Specify a value in decimal degrees i.e: -123.45';
$lang['info_center_lon'] = 'The Center longitude is optional.  If specified it will be used for centering the map. Specify a value in decimal degrees i.e: -123.45';
$lang['info_combine_points'] = 'If selected, points that are within a specified radius of each other will be combined into one marker on the map.  This functionality is useful if multiple entries exist at the same (or almost the same) coordinates, to ease in selection.  This functionality is independant of the map zoom level.';
$lang['info_controls'] = 'Sollten Zoom und Pan-Regler angezeigt werden?';
$lang['info_controls_size'] = 'Geben Sie die Gr&ouml;&szlig;e der Steuerelemente auf der Karte an';
$lang['info_default_icon'] = 'Standard Icon wird verwendet, wenn kein anderes Icon f&uuml;r ein Kartenpunkt angegeben ist';
$lang['info_directions'] = 'Erlaube anfordern der Richtungen von und zu einem Kartenpunkt';
$lang['info_directions_dest'] = 'Specify how directions should be handled.  Should they be displayed in a new window, or in the map panel';
$lang['info_directions_units'] = 'Specify how the units should be displayed for directions.  Metric, or imperial.';
$lang['info_height'] = 'Specify a map height (in pixels)';
$lang['info_icon_selection'] = 'By default, which icon should be preferred for markers when the category panel is displayed';
$lang['info_info_trigger'] = 'Specify what should trigger the opening of the info window';
$lang['info_info_window'] = 'Should an information window be displayed for each map point?';
$lang['info_infowindow_height'] = 'Geben Sie eine H&ouml;he (in Pixeln) f&uuml;r das Info Fenster an';
$lang['info_infowindow_width'] = 'Geben Sie eine Breite (in Pixeln) f&uuml;r das Info Fenster an';
$lang['info_map_type'] = 'Geben Sie den Standard Kartentyp an (Wenn das Bedienelement f&uuml;r den Kartentyp aktiviert ist, kann der Benutzer den Typ &auml;ndern,  nachdem die Karte geladen ist)';
$lang['info_nav_control_opt'] = 'Specify the type of navigation controls for the map';
$lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
$lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area';
$lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map';
$lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable of providing latitude and longitude information.  Do you want to enable this?';
$lang['info_sidebar'] = 'Should a sidebar containing all map points be displayed?';
$lang['info_sv_controls'] = 'Soll das Bedienelement f&uuml;r StreetView auf der Karte angezegit werden?';
$lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
$lang['info_sysdflt_baloon_template'] = 'Standard &quot;Ballon&quot; Template';
$lang['info_sysdflt_category_template'] = 'Standard &quot;Kategorie&quot; Listen-Template';
$lang['info_sysdflt_dirform_template'] = 'Standard &quot;Richtungs-Formular&quot; Template';
$lang['info_sysdflt_js_template'] = 'Standard Javascript Template';
$lang['info_sysdflt_map_template'] = 'Standard Karten template';
$lang['info_sysdflt_sidebar_template'] = 'Standard Seitenleisten Template';
$lang['info_sysdflt_template'] = 'This form provides the ability to specify the content that will be displayed when you create a new template of this type.  Editing the content in this form will have no immediate effect on your website';
$lang['info_type_control_opt'] = 'Geben Sie an, wie das Bedienelement f&uuml;r den Kartentyp angezeigt werden soll';
$lang['info_width'] = 'Geben Sie eine Kartenbreite an (in Pixeln)';
$lang['infowindow_width'] = 'Breite des Info Fensters';
$lang['infowindow_height'] = 'H&ouml;he des Info Fensters';
$lang['info_type_controls'] = 'Benutzer erlauben, den Kartentyp zu &auml;ndern?';
$lang['info_zoom'] = 'Geben Sie eine erste Zoomstufe (beachten Sie, dass dieser Parameter wirkungslos ist, wenn &quot;Zoom umfassen&quot;  verwendet wird)';
$lang['info_zoom_encompass'] = 'Soll die Zoomstufe der Karte alle Punkte umfassen?';
$lang['js_template'] = 'Javascript Template';
$lang['large'] = 'Gro&szlig;';
$lang['latitude'] = 'Breitengrad';
$lang['latlong'] = 'Breitengrad / L&auml;ngengrad';
$lang['location'] = 'Ort';
$lang['longitude'] = 'L&auml;ngengrad';
$lang['make_default'] = 'Dieses Icon als Standard-Icon festlegen';
$lang['marker_categories'] = 'Marker Kategorien';
$lang['marker_icons'] = 'Marker Symbole';
$lang['marker_skipped'] = 'Geolocation (adresse lat/long) fehlgeschlagen.. Marker &quot;%s&quot; &uuml;bersprungen';
$lang['map'] = 'Karte';
$lang['maps'] = 'Karten';
$lang['maptemplate_addedit'] = 'Ein Karten-Template hinzuf&uuml;gen/bearbeiten';
$lang['map_name'] = 'Kartenname';
$lang['map_template'] = 'Mappen Template';
$lang['map_templates'] = 'Karten-Templates';
$lang['map_type'] = 'Kartentyp';
$lang['metric'] = 'Metrisch';
$lang['moddescription'] = 'Ein einfaches Modul zum Erstellen von Google Maps';
$lang['mouseover'] = 'MouseOver ';
$lang['msg_addresscache_cleared'] = 'Geolocation Cache geleert';
$lang['msg_categoryadded'] = 'Kategorie hinzugef&uuml;gt';
$lang['msg_categorydeleted'] = 'Kategorie gel&ouml;scht';
$lang['msg_categoryupdated'] = 'Kategorie aktualisiert';
$lang['msg_default_icon_uchanged'] = 'Das Standard-Icon wurde ge&auml;ndert';
$lang['msg_icons_reset'] = 'Die Icons wurden auf die programmseitigen Voreinstellungen zur&uuml;ckgesetzt';
$lang['msg_icon_removed'] = 'Das Icon wurde aus der Datenbank entfernt. Es wurden keine Dateien gel&ouml;scht';
$lang['msg_icon_updated'] = 'Die Icon-Information wurde ge&auml;ndert';
$lang['name'] = 'Name ';
$lang['nav_control_opt'] = 'Gr&ouml;&szlig;e der Kontroll-Navigation ';
$lang['none'] = 'Keine(r)';
$lang['panel'] = 'Feld';
$lang['points'] = 'Punkt';
$lang['point_combine_fudge'] = 'Geben Sie einen Radius an, welcher bestimmt welche Punkte zusammengefasst werden sollen.';
$lang['point_combine_icon'] = 'Symbol f&uuml;r Kombinierte punkte';
$lang['point_name'] = 'Punktname';
$lang['point_type'] = 'Punkttyp';
$lang['policy_cachefirst'] = 'Lese-Zwischenspeicher zuerst, dann Online-Abfrage f&uuml;rAdresse';
$lang['policy_cacheonly'] = 'Verwenden Sie immer den Zwischenspeicher';
$lang['policy_nocache'] = 'Verwenden niemals den Zwischenspeicher (Online-Abfrage nur)';
$lang['postinstall'] = 'Das Modul CGGoogleMaps wurde installiert.';
$lang['postuninstall'] = 'Das Modul CGGoogleMaps und alle relevanten Daten wurden entfernt';
$lang['preferences'] = 'Voreinstellungen';
$lang['prompt_bounds_fudge'] = 'Zoom Encompass Bounds Fudge';
$lang['prompt_categories'] = 'Kategorien';
$lang['prompt_directions'] = 'Richtungen';
$lang['prompt_from_here'] = 'Von hier';
$lang['prompt_icon_selection'] = 'Icon Auswahl';
$lang['prompt_info_window'] = 'Info-Fenster anzeigen';
$lang['prompt_info_trigger'] = 'Info-Fenster Ausl&ouml;ser anzeigen';
$lang['prompt_lookup_policy'] = 'Lookup Regel';
$lang['prompt_lookup_service'] = 'Suchdienst';
$lang['prompt_to_here'] = 'Hierher';
$lang['prompt_sensor'] = 'Liefere Informationen der Geographische Lage , an die Karte';
$lang['prompt_zoom'] = 'Zoomstufe';
$lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul entfernen?';
$lang['reset'] = 'Zur&uuml;cksetzen';
$lang['reset_icons'] = 'Icons zur&uuml;cksetzen';
$lang['satellite'] = 'Satelliten-Modus';
$lang['scalecontrols'] = 'Ma&szlig;stab anzeigen';
$lang['set_dflt_map'] = 'Die Karte als Standard festlegen';
$lang['show_category_panel'] = 'Kategorie-Feld anzeigen';
$lang['sidebar'] = 'Sidebar anzeigen';
$lang['sidebar_template'] = 'Seitenleisten Template';
$lang['small'] = 'Klein';
$lang['submit'] = 'Absenden';
$lang['sv_controls'] = 'Streetview Steuerung anzeigen';
$lang['sv_radius'] = 'Streetview Suchradius';
$lang['tab_advanced'] = 'Erweitert';
$lang['tab_directions'] = 'Richtungen';
$lang['tab_jstemplate'] = 'Javascript Template';
$lang['tab_settings'] = 'Einstellungen';
$lang['tab_maptemplate'] = 'Karten Template';
$lang['text'] = 'Text ';
$lang['to'] = 'Nach';
$lang['type'] = 'Typ';
$lang['type_controls'] = 'Typenkontrolle anzeigen';
$lang['type_control_opt'] = 'Typenkontrollen Optionen';
$lang['url'] = 'URL ';
$lang['use_category_icon'] = 'Bevorzugter Kategorie Icon';
$lang['use_marker_icon'] = 'Bevorzugter Marker Icon';
$lang['width'] = 'Breite';
$lang['window'] = 'Fenster';
$lang['zoom_encompass'] = 'Zoom Encompass';
$lang['qca'] = 'P0-1458450664-1284573084918';
$lang['utma'] = '156861353.423163579.1322242094.1322242094.1322242094.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1322242094.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
?>